## Origin of example data

### Neurons

The example neurons provided are olfactory projection neurons of the DA1
glomerulus from the Janelia hemibrain data set
(see [here](https://neuprint.janelia.org)) [1].

### Volumes
Example volumes provided are based on light microscopy images of the fruit
fly brain and were transformed into hemibrain space. See the
[`nat`](https://github.com/jefferis/nat) ecosystem for R.
In particular [`nat.jrcbrains`](https://github.com/jefferislab/nat.jrcbrains).

### References
[1] Louis K. Scheffer et al., eLife. 2020. doi: 10.7554/eLife.57443
A connectome and analysis of the adult Drosophila central brain
